#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_FINITE
#undef HAVE_STPCPY
#undef HAVE_ORBIT
#undef HAVE_GTK_SELECTION_ADD_TARGET
#undef HAVE_GUILE
#undef ENABLE_BONOBO
#undef USING_OAF
#undef ENABLE_GB
#undef HAVE_IEEEFP_H
#undef HAVE_IEEE754_H
#undef ENABLE_GNOME
#undef HAVE_PSPELL
#undef ENABLE_EVOLUTION

#undef GNUMERIC_VERSION

#undef USE_WM_ICONS

@BOTTOM@
